==> moodle-1.4.5.tgz: moodle/lang/sl/auth.php <==
<?PHP // $Id: auth.php,v 1.1.2.3 2004/12/17 16:19:30 moodler Exp $ 
      // auth.php - created with Moodle 1.3.1 (2004052501)


$string['auth_dbdescription'] = 'S to izbiro doloite eksterno bazo podatkov za preverjanje veljavnosti uporabnikega imena in gesla. Pri novem raunu za portal (moodle) je mono obstojee podatke iz baze prenesti (prekopirati).';
$string['auth_dbextrafields'] = 'Ta polja so izbirna. Vrednosti polj v portalu lahko vnaprej zapolnite <B>z vrednostmi polj v eksterni bazi</B>. e pustite polja prazna, bodo vpisane privzete vrednosti. Po prijavi sme uporabnik spreminjati vsa polja.';
$string['auth_dbfieldpass'] = 'Stolpec, ki vsebuje geslo';
$string['auth_dbfielduser'] = 'Stolpec, ki vsebuje uporabniko ime';
$string['auth_dbhost'] = 'Naziv raunalnika (podatkovnega strenika)';
$string['auth_dbname'] = 'Naziv (ime) baze podatkov';
$string['auth_dbpass'] = 'Geslo za navedeno uporabniko ime';
$string['auth_dbpasstype'] = 'Doloite format uporabljenega gesla. Enkripcija po algoritmu MD5 je koristna za povezovanje z drugimi spletnimi reitvami kot je npr. PostNuke';
$string['auth_dbtable'] = 'Naziv tabele v bazi ';
$string['auth_dbtitle'] = 'Uporaba eksterne baze';
$string['auth_dbtype'] = 'Tip baze podatkov (glej podrobnosti: <a href=\"../lib/adodb/readme.htm#drivers\">ADOdb documentation</a>)';
$string['auth_dbuser'] = 'Uporabniko ime s pravico branja baze';
$string['auth_emaildescription'] = 'Potrjevanje z epoto je privzeti nain avtentikacije.  Ko uporabnik vnese novi ime in geslo, portal polje epoto na navedeni naslov. Sporoilo vsebuje vareno povezavo na stran, kjer uporabnik potrdi svoj novi raun. Pri vseh naslednjih prijavah portal preverja ime in geslo v svoji bazi.';
$string['auth_emailtitle'] = 'Na epoti temeljea avtentikacija';
$string['auth_imapdescription'] = 'Veljavnost uporabnikega imena in gesla preveri strenik IMAP.';
$string['auth_imaphost'] = 'Naslov strenika IMAP. Uporabite tevilko IP - ne DNS.';
$string['auth_imapport'] = 'tevilka vrat strenika IMAP (obiajno 143 ali 993).';
$string['auth_imaptitle'] = 'Uporabi strenik IMAP';
$string['auth_imaptype'] = 'Tip strenika IMAP.Streniki IMAP lahko uporabljajo razline naine avtentikacije in dogovarjanja.';
$string['auth_ldap_bind_dn'] = 'e boste uporabljali LDAP, doloite uporabnika npr. \'cn=ldapuser,ou=public,o=org\'';
$string['auth_ldap_bind_pw'] = 'Geslo za LDAP.';
$string['auth_ldap_contexts'] = 'Doloite sezname uporabnikov. Sezname loite s \';\'. Primer: \'ou=users,o=org; ou=others,o=org\'';
$string['auth_ldap_create_context'] = 'e ste izbrali potrjevanje raunov preko epote, doloite e mesto kreiranja. To mesto mora biti razlino od drugih uporabnikov (iz varnostnih razlogov). Tega niza ni potrebno dodajati v spremenljivko ldap_context-variable, saj bo portal samodejno iskal uporabnike na tem mestu.';
$string['auth_ldap_creators'] = 'Seznam skupin uporabnikov, ki smejo kreirati nove predmete (npr.\'cn=teachers,ou=staff,o=myorg\'). Ve seznamov loite s \';\'';
$string['auth_ldap_host_url'] = 'Doloite URL LDAP strenika (npr. \'ldap://ldap.myorg.com/\' or \'ldaps://ldap.myorg.com/\'';
$string['auth_ldap_memberattribute'] = 'Doloite atribute lana skupine (obiajno \'member\')';
$string['auth_ldap_search_sub'] = 'Doloite vrednost <> 0 kadar iete uporabnika v podkontekstu.';
$string['auth_ldap_update_userinfo'] = 'Spremeni podatke o uporabniku (ime, priimek, naslov..) na portalu iz strenika LDAP (podrobnosti preslikave na  /auth/ldap/attr_mappings.php)';
$string['auth_ldap_user_attribute'] = 'Atribut za imenovanje/iskanje uporabnika (obiajno \'cn\').';
$string['auth_ldap_version'] = 'Verzija protokola LDAP na streniku.';
$string['auth_ldapdescription'] = 'Ta nain omogoa avtentikacijo preko strenika LDAP.
                                  e je vpisano uporabniko ime in geslo veljavno, portal kreira novega uporabnika 
                                  v svoji bazi. Ta modul bere uporabnikove atribute v LDAP in jih napolni v polja portala. 
                                  Pri naslednjih prijavah se preverjajo l ime in geslo.';
$string['auth_ldapextrafields'] = 'Ta polja so izbirna.  Vnaprej prenesene vrednosti iz <B>LDAP polj</B> doloite tukajt. <P>e pustite polja prazna, se ni ne prenese. Vpisane bodo privzete vrednosti.<P>V vsakem primeru bodo uporabniki smeli spreminjati svoje podatke ob naslednjih prijavah.';
$string['auth_ldaptitle'] = 'Uporabi strenik LDAP';
$string['auth_manualdescription'] = 'S tem pristopom uporabniki ne morejo kreirali lastnih raunov. Vse raune mora rono kreirati administrator.';
$string['auth_manualtitle'] = 'Le roni uporabniki rauni';
$string['auth_multiplehosts'] = 'Doloite lahko ve strenikov(npr. host1.com;host2.com;host3.com)';
$string['auth_nntpdescription'] = 'Veljavnost uporabnikega imena in gesla preveri strenik NNTP.';
$string['auth_nntphost'] = 'Naslov strenika NNTP. Uporabite tevilko IP - ne DNS.';
$string['auth_nntpport'] = 'tevilka vrat strenika NNTP (obiajno 119).';
$string['auth_nntptitle'] = 'Uporabi strenik  NNTP.';
$string['auth_nonedescription'] = 'Uporabniki takoj pridobijo uporabniki raun - brez avtentikacije v eksterni bazi in brez potrjevanja z epoto.  Ta pristop ni priporoljiv iz varnostnih in administrativnih razlogov.';
$string['auth_nonetitle'] = 'Brez avtentikacije';
$string['auth_pop3description'] = 'Veljavnost uporabnikega imena in gesla preveri strenik POP3';
$string['auth_pop3host'] = 'Naslov strenika POP3. Uporabite tevilko IP - ne DNS.';
$string['auth_pop3port'] = 'tevilka vrat strenika POP3 (obiajno 110).';
$string['auth_pop3title'] = 'Uporabi strenik POP3';
$string['auth_pop3type'] = 'Tip strenika. e strenik uporablja varnostni certifikat, izberite pop3cert.';
$string['auth_user_create'] = 'Kreiranje uporabnikov omogoeno';
$string['auth_user_creation'] = 'Novi (anonimni) uporabniki smejo kreirati raune na ekstrenih avtentikacijskih virih in jih potrjevati z epoto. e to dovolite, doloite e posebne opcije za kreiranje uporabnikov';
$string['auth_usernameexists'] = 'Izbrano ime e obstaja. Doloite novega.';
$string['authenticationoptions'] = 'Izbire avtentikacije';
$string['authinstructions'] = 'Na tem mestu napiite navodila za kreiranje uporabnikih raunov. To besedilo se prikae na strani za prijavo.  e ne napiete navodil, potem bo stran prazna.';
$string['changepassword'] = 'Spremeni geslo URL';
$string['changepasswordhelp'] = 'Doloite mesto za obnovo ali spremembo imena/gesla, e ga/ju uporabnik pozabi. Na strani za prijavo se izpie gumb. e pustite prazno, se gumb ne bo izpisal.';
$string['chooseauthmethod'] = 'Izberite nain avtentikacije: ';
$string['guestloginbutton'] = 'Gumb za prijavo gosta';
$string['instructions'] = 'Navodila';
$string['md5'] = 'Enkripcija MD5';
$string['plaintext'] = 'tekst';
$string['showguestlogin'] = 'Gumb za prijavo gosta lahko skrijete ali prikaete na vstopni strani.';

?>

==> moodle-1.5.3.tgz: moodle/lang/sl/auth.php <==
<?PHP // $Id$ 
      // auth.php - created with Moodle 1.3.1 (2004052501)


$string['auth_dbdescription'] = 'S to izbiro doloite eksterno bazo podatkov za preverjanje veljavnosti uporabnikega imena in gesla. Pri novem raunu za portal (moodle) je mono obstojee podatke iz baze prenesti (prekopirati).';
$string['auth_dbextrafields'] = 'Ta polja so izbirna. Vrednosti polj v portalu lahko vnaprej zapolnite <b>z vrednostmi polj v eksterni bazi</b>. e pustite polja prazna, bodo vpisane privzete vrednosti. Po prijavi sme uporabnik spreminjati vsa polja.';
$string['auth_dbfieldpass'] = 'Stolpec, ki vsebuje geslo';
$string['auth_dbfielduser'] = 'Stolpec, ki vsebuje uporabniko ime';
$string['auth_dbhost'] = 'Naziv raunalnika (podatkovnega strenika)';
$string['auth_dbname'] = 'Naziv (ime) baze podatkov';
$string['auth_dbpass'] = 'Geslo za navedeno uporabniko ime';
$string['auth_dbpasstype'] = 'Doloite format uporabljenega gesla. Enkripcija po algoritmu MD5 je koristna za povezovanje z drugimi spletnimi reitvami kot je npr. PostNuke';
$string['auth_dbtable'] = 'Naziv tabele v bazi ';
$string['auth_dbtitle'] = 'Uporaba eksterne baze';
$string['auth_dbtype'] = 'Tip baze podatkov (glej podrobnosti: <a href=\"../lib/adodb/readme.htm#drivers\">ADOdb documentation</a>)';
$string['auth_dbuser'] = 'Uporabniko ime s pravico branja baze';
$string['auth_emaildescription'] = 'Potrjevanje z epoto je privzeti nain avtentikacije.  Ko uporabnik vnese novi ime in geslo, portal polje epoto na navedeni naslov. Sporoilo vsebuje vareno povezavo na stran, kjer uporabnik potrdi svoj novi raun. Pri vseh naslednjih prijavah portal preverja ime in geslo v svoji bazi.';
$string['auth_emailtitle'] = 'Na epoti temeljea avtentikacija';
$string['auth_imapdescription'] = 'Veljavnost uporabnikega imena in gesla preveri strenik IMAP.';
$string['auth_imaphost'] = 'Naslov strenika IMAP. Uporabite tevilko IP - ne DNS.';
$string['auth_imapport'] = 'tevilka vrat strenika IMAP (obiajno 143 ali 993).';
$string['auth_imaptitle'] = 'Uporabi strenik IMAP';
$string['auth_imaptype'] = 'Tip strenika IMAP.Streniki IMAP lahko uporabljajo razline naine avtentikacije in dogovarjanja.';
$string['auth_ldap_bind_dn'] = 'e boste uporabljali LDAP, doloite uporabnika npr. \'cn=ldapuser,ou=public,o=org\'';
$string['auth_ldap_bind_pw'] = 'Geslo za LDAP.';
$string['auth_ldap_contexts'] = 'Doloite sezname uporabnikov. Sezname loite s \';\'. Primer: \'ou=users,o=org; ou=others,o=org\'';
$string['auth_ldap_create_context'] = 'e ste izbrali potrjevanje raunov preko epote, doloite e mesto kreiranja. To mesto mora biti razlino od drugih uporabnikov (iz varnostnih razlogov). Tega niza ni potrebno dodajati v spremenljivko ldap_context-variable, saj bo portal samodejno iskal uporabnike na tem mestu.';
$string['auth_ldap_creators'] = 'Seznam skupin uporabnikov, ki smejo kreirati nove predmete (npr.\'cn=teachers,ou=staff,o=myorg\'). Ve seznamov loite s \';\'';
$string['auth_ldap_host_url'] = 'Doloite URL LDAP strenika (npr. \'ldap://ldap.myorg.com/\' or \'ldaps://ldap.myorg.com/\'';
$string['auth_ldap_memberattribute'] = 'Doloite atribute lana skupine (obiajno \'member\')';
$string['auth_ldap_search_sub'] = 'Doloite vrednost <> 0 kadar iete uporabnika v podkontekstu.';
$string['auth_ldap_update_userinfo'] = 'Spremeni podatke o uporabniku (ime, priimek, naslov..) na portalu iz strenika LDAP (podrobnosti preslikave na  /auth/ldap/attr_mappings.php)';
$string['auth_ldap_user_attribute'] = 'Atribut za imenovanje/iskanje uporabnika (obiajno \'cn\').';
$string['auth_ldap_version'] = 'Verzija protokola LDAP na streniku.';
$string['auth_ldapdescription'] = 'Ta nain omogoa avtentikacijo preko strenika LDAP.
                                  e je vpisano uporabniko ime in geslo veljavno, portal kreira novega uporabnika 
                                  v svoji bazi. Ta modul bere uporabnikove atribute v LDAP in jih napolni v polja portala. 
                                  Pri naslednjih prijavah se preverjajo l ime in geslo.';
$string['auth_ldapextrafields'] = 'Ta polja so izbirna.  Vnaprej prenesene vrednosti iz <b>LDAP polj</b> doloite tukajt. <br />e pustite polja prazna, se ni ne prenese. Vpisane bodo privzete vrednosti.<br />V vsakem primeru bodo uporabniki smeli spreminjati svoje podatke ob naslednjih prijavah.';
$string['auth_ldaptitle'] = 'Uporabi strenik LDAP';
$string['auth_manualdescription'] = 'S tem pristopom uporabniki ne morejo kreirali lastnih raunov. Vse raune mora rono kreirati administrator.';
$string['auth_manualtitle'] = 'Le roni uporabniki rauni';
$string['auth_multiplehosts'] = 'Doloite lahko ve strenikov(npr. host1.com;host2.com;host3.com)';
$string['auth_nntpdescription'] = 'Veljavnost uporabnikega imena in gesla preveri strenik NNTP.';
$string['auth_nntphost'] = 'Naslov strenika NNTP. Uporabite tevilko IP - ne DNS.';
$string['auth_nntpport'] = 'tevilka vrat strenika NNTP (obiajno 119).';
$string['auth_nntptitle'] = 'Uporabi strenik  NNTP.';
$string['auth_nonedescription'] = 'Uporabniki takoj pridobijo uporabniki raun - brez avtentikacije v eksterni bazi in brez potrjevanja z epoto.  Ta pristop ni priporoljiv iz varnostnih in administrativnih razlogov.';
$string['auth_nonetitle'] = 'Brez avtentikacije';
$string['auth_pop3description'] = 'Veljavnost uporabnikega imena in gesla preveri strenik POP3';
$string['auth_pop3host'] = 'Naslov strenika POP3. Uporabite tevilko IP - ne DNS.';
$string['auth_pop3port'] = 'tevilka vrat strenika POP3 (obiajno 110).';
$string['auth_pop3title'] = 'Uporabi strenik POP3';
$string['auth_pop3type'] = 'Tip strenika. e strenik uporablja varnostni certifikat, izberite pop3cert.';
$string['auth_user_create'] = 'Kreiranje uporabnikov omogoeno';
$string['auth_user_creation'] = 'Novi (anonimni) uporabniki smejo kreirati raune na ekstrenih avtentikacijskih virih in jih potrjevati z epoto. e to dovolite, doloite e posebne opcije za kreiranje uporabnikov';
$string['auth_usernameexists'] = 'Izbrano ime e obstaja. Doloite novega.';
$string['authenticationoptions'] = 'Izbire avtentikacije';
$string['authinstructions'] = 'Na tem mestu napiite navodila za kreiranje uporabnikih raunov. To besedilo se prikae na strani za prijavo.  e ne napiete navodil, potem bo stran prazna.';
$string['changepassword'] = 'Spremeni geslo URL';
$string['changepasswordhelp'] = 'Doloite mesto za obnovo ali spremembo imena/gesla, e ga/ju uporabnik pozabi. Na strani za prijavo se izpie gumb. e pustite prazno, se gumb ne bo izpisal.';
$string['chooseauthmethod'] = 'Izberite nain avtentikacije: ';
$string['guestloginbutton'] = 'Gumb za prijavo gosta';
$string['instructions'] = 'Navodila';
$string['md5'] = 'Enkripcija MD5';
$string['plaintext'] = 'tekst';
$string['showguestlogin'] = 'Gumb za prijavo gosta lahko skrijete ali prikaete na vstopni strani.';

?>
